from distutils.core import setup

setup(
    name='gargantua',
    packages=['gargantua'],
    version='0.1',
    description='Tiny Mysql query builder and runner Semih Sipahi',
    author='Semih Sipahi',
    author_email='semihsipahi@linux.com',
    url='https://github.com/semihsipahi/gargantua',
    download_url='https://github.com/semihsipahi/gargantua/releases/tag/0.1',
    keywords=[],
    classifiers=[],
)

